@@ -1,18 +1,18 @@
 import random
-from typing import Any, TYPE_CHECKING
+from typing import TYPE_CHECKING, Union
 
 import attr
 
-from testcase_maker.values.base import BaseValue
+from testcase_maker.value import Value
 
 if TYPE_CHECKING:
-    from testcase_maker.core import Resolver
+    from testcase_maker.resolver import Resolver
 
 
 @attr.define()
-class RandomInt(BaseValue):
-    min: int = attr.ib()
-    max: int = attr.ib()
+class RandomInt(Value):
+    min: Union[int, "Value"] = attr.ib()
+    max: Union[int, "Value"] = attr.ib()
 
     def generate(self, resolver: "Resolver") -> int:
         min_range = resolver.resolve(self.min, int)
